<!--隐患档案查询-->
<template>
  <div class="mobile-device">
    <!--  头部  -->
    <div class="header">
      <van-search
        v-model="customQueryPrams.caseCode"
        show-action
        label="案件编码"
        placeholder="请输入案件编码"
        @blur="searchData"
      >
        <template #action>
          <van-button type="info" size="mini" @click="showPopup('querySearchPopup')">打开高级搜索</van-button>
        </template>
      </van-search>
    </div>

    <van-pull-refresh
      v-model="refreshing"
      @refresh="onRefresh"
      class="van-hairline--top"
      @scroll.native="listScroll"
      ref="refresh"
    >
      <van-list
        v-model="loading"
        :finished="finished"
        finished-text="没有更多了"
        @load="onLoad"
        :immediate-check="false"
      >
        <div
          v-for="(item, index) in listData"
          :key="index"
          class="device van-hairline--bottom"
          :class="{myStyle: index === listData.length - 1}"
        >
          <div class="device-item">
            <div class="device-item-top">
              <div class="device-item-top-left">
                <van-tag
                  v-if="item.caseStatus === '0' || !item.caseStatus"
                  size="medium"
                  type="warning"
                  plain
                >
                  {{ dictionaryEscape(caseStatusOpt, item.caseStatus || '0') }}
                </van-tag>
                <van-tag
                  v-else-if="item.caseStatus === '1' || item.caseStatus === '2' "
                  size="medium"
                  type="primary"
                  plain
                >
                  {{ dictionaryEscape(caseStatusOpt, item.caseStatus) }}
                </van-tag>
                <van-tag
                  v-else
                  size="medium"
                  type="success"
                  plain
                >
                  {{ dictionaryEscape(caseStatusOpt, item.caseStatus) }}
                </van-tag>
                <span class="code">{{ item.caseCode || '-' }}</span>
              </div>
            </div>
            <div class="device-item-content">
              <p>
                <span class="label">案件类型：</span>
                <span class="value">
                   {{ dictionaryEscape(caseTypeOpt, item.caseType) || '-' }}
                </span>
              </p>
              <p>
                <span class="label">案件来源：</span>
                <span class="value">
                   {{ dictionaryEscape(caseSrcOpt, item.caseSrc) || '-' }}
                  </span>
              </p>
              <p>
                <span class="label">案由：</span>
                <span class="value">{{ item.caseReason || '-' }}</span>
              </p>
              <p>
                <span class="label">巡逻地址：</span>
                <span class="value">{{ item.walkAddr || '-' }}</span>
              </p>
              <p>
                <span class="label">巡逻时间：</span>
                <span class="value">{{ item.walkTime || '-' }}</span>
              </p>
            </div>
            <div class="device-item-bottom">
              <van-button type="info" size="mini" v-if="!item.caseStatus || item.caseStatus === '0'"
                          @click="boxClick(item)">
                案件录入
              </van-button>
              <van-button type="primary" size="mini" v-else @click="boxClick(item)">
                详情
              </van-button>
            </div>
          </div>
        </div>
      </van-list>
    </van-pull-refresh>


    <!-- 列表筛选弹层 -->
    <QuerySearchPopup
      :querySearchPopup.sync="querySearchPopup"
      :customQueryPrams="customQueryPrams"
      :caseStatusOpt="caseStatusOpt"
      :caseSrcOpt="caseSrcOpt"
      :caseTypeOpt="caseTypeOpt"
      @searchData="searchData"
    />
  </div>
</template>

<script>
import {Toast} from 'vant'
import QuerySearchPopup from './components/QuerySearchPopup/index.vue'
import dictUtils from '@/components/dict/DictSelectUtils'
import {listData} from '@/api/Mobile/caseHandling'
import {dictionaryEscape} from '@/utils/dictionary'

const {getDictItemsFromCache} = dictUtils // 解构出获取字典函数

export default {
  name: 'MyCase',
  components: {QuerySearchPopup},
  // 隐患档案查询
  data() {
    return {
      // 自定义请求参数配置对象
      customQueryPrams: {
        pageSize: 10,
        page: 1,
        caseType: '',
        caseSrc: '',
        caseStatus: ''
      },
      sorter: [],
      listData: [],// 列表数据
      caseStatusOpt: dictUtils.getDictItemsFromCache('tybagl-ajzt') || [], // 案件状态
      caseSrcOpt: dictUtils.getDictItemsFromCache('tybagl-ajl') || [], // 案件来源
      caseTypeOpt: dictUtils.getDictItemsFromCache('tybagl-ajlx') || [], // 案件类型
      loading: false, // 列表是否触发loading
      finished: false, // 列表是否加载完成
      refreshing: false, // 列表是否开始下拉刷新
      querySearchPopup: false,// 搜索弹层
      listScrollTop: 0
    }
  },
  watch: {
    $route(to, from) {
      const {name} = from
      const {query: {type = ''}} = to
      if (name === 'draftDetails' && type === 'edit') {
        this.searchData()
      }
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    queryParams() {
      const {pageSize, page, ...item} = this.customQueryPrams
      /*
      * 定义 escapeOpt 字段对应字典名 对象，后续进行字段的翻译逻辑(应对于Vant2下拉框无转义功能)
      *  为重新加工结构赋值的新请求配置参数
      * */
      const querys = [
        {property: 'caseCode', operation: 'LIKE'},
        {property: 'caseSrc', operation: 'EQUAL'},
        {property: 'caseType', operation: 'EQUAL'},
        {property: 'caseStatus', operation: 'EQUAL'}
      ]
      const escapeOpt = {
        caseSrc: 'caseSrcOpt',
        caseType: 'caseTypeOpt',
        caseStatus: 'caseStatusOpt'
      }
      return {
        pageBean: {pageSize, page},
        querys: querys.flatMap(i => {
          // 获取value值优先级：customQueryPrams.value > querys[i].value
          let value = item[i.property] || i.value || ''
          if (Array.isArray(value) && !value.length) return []
          if (value === '') return []
          let escape = this[escapeOpt[i.property]]  // 找寻翻译配置项
          if (escape) value = this.dictionaryEscape(escape, value, {dictionaryType: false})
          return {operation: 'LIKE', group: 'main', relation: 'AND', ...i, value}
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  created() {
    this.getListData()
  },
  activated() {
    if (this.$refs.refresh.$el) {
      this.$refs.refresh.$el.scrollTop = this.listScrollTop
    }
  },
  methods: {
    // 列表滚动监听
    listScroll(e) {
      this.listScrollTop = e.target.scrollTop
    },

    // 字典转义(转义、翻译)
    dictionaryEscape,

    // 跳转设备详情
    boxClick({id = '', caseStatus = ''}) {
      if (!id) return Toast.fail('案件信息错误')
      let name = (!caseStatus || caseStatus === '0') ? 'draftDetails' : 'disposalDetails'
      this.$router.push({
        name,
        query: {id}
      })
    },

    // 触底时触发
    onLoad() {
      this.customQueryPrams.page++
      this.getListData(_ => this.loading = false)
    },

    // 下拉时触发
    onRefresh() {
      this.finished = false
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData(_ => this.refreshing = false)
    },

    // 打开弹层
    showPopup(popupName) {
      this[popupName] = true
    },

    // 获取列表数据
    async getListData(callback) {
      const {rows, total} = await listData(this.queryParams)
      const {pageSize, page} = this.customQueryPrams
      this.listData = this.listData.concat(rows)
      this.$nextTick(_ => callback && callback())
      if (pageSize * page >= total) this.finished = true
    },

    // 查询/重置按钮点击
    searchData() {
      this.finished = false
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData()
    },

    // 列表数据重置
    listDataReset() {
      Object.assign(this.$data, this.$options.data())
      this.getListData()
    }
  }
}
</script>


<style lang="scss" scoped>
@import '@/assets/css/element-variables';

.mobile-device {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;

  .header {
    border-bottom: 2px solid #e1e1e1;

    ::v-deep .van-search {
      box-sizing: border-box;
      padding: 40px;

      .van-search__action {
        display: flex;
        align-items: center;
      }
    }
  }

  .van-hairline--top {
    flex: 1;
    height: 0;
    overflow: auto;

    .device {
      background-color: #f9f9f9;
      padding: 40px 40px 20px 40px;
      box-sizing: border-box;
      color: $--mobile-text-sub;
      width: 100%;

      .device-item {
        display: flex;
        flex-direction: column;
        column-gap: 100px;
        background-color: #fff;
        border-radius: 40px;
        padding: 80px 80px 60px 60px;
        box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.1), 0 6px 20px 0 rgba(0, 0, 0, 0.1);

        .device-item-top {
          display: flex;
          width: 100%;
          justify-content: space-between;
          align-items: center;


          .device-item-top-left {
            display: flex;
            align-items: center;
            column-gap: 40px;

            .van-tag {
              min-width: 35PX;
              display: flex;
              justify-content: center;
              font-weight: 600;
            }

            .code {
              font-weight: bold;
              color: #555;
            }
          }
        }

        .device-item-content {
          display: flex;
          flex-direction: column;
          row-gap: 30px;
          flex: 1;
          margin-top: 50px;

          p {
            margin: 0;
            display: flex;

            .label {
              color: #333;
              font-size: 60px;
              flex: 1.9;
            }

            .value {
              font-size: 60px;
              flex: 8;
              word-break: break-all;
              overflow: hidden;
              display: -webkit-box;
              -webkit-line-clamp: 3;
              -webkit-box-orient: vertical;
            }
          }
        }

        .device-item-bottom {
          display: flex;
          justify-content: flex-end;

          ::v-deep .van-button {
            width: 60PX;
          }
        }
      }
    }

  }

}

::v-deep .van-search__label {
  font-size: 12PX;
}


</style>


<style lang="scss">
@import '@/assets/css/vant-custom';
</style>


